#!/bin/bash -e

echo "================= Adding some global settings ==================="
mkdir -p "$HOME/.ssh/"
mv /u20arm/config "$HOME/.ssh/"
mv /u20arm/90forceyes /etc/apt/apt.conf.d/
touch "$HOME/.ssh/known_hosts"
mkdir -p /etc/drydock

echo "================= Installing basic packages ================"
apt-get update
apt-get install ca-certificates
apt-get install -y \
curl \
gettext \
ftp \
groff \
mercurial \
openssh-client \
smbclient \
software-properties-common \
sudo \
wget \
unzip \
ca-certificates \
apt-transport-https \
gnupg

echo "================= Installing Python packages =================="
apt-get install -q -y \
python3-pip \
python3-software-properties \
python3-dev

sudo python3 -m pip install --upgrade pip

sudo pip3 install virtualenv
sudo pip3 install cryptography
sudo pip3 install -q pyOpenSSL

#Link: https://jqlang.github.io/jq/download/
#latest is 1.7 but ubuntu20 is supporting 1.6
export JQ_VERSION=1.6*
echo "================= Adding JQ $JQ_VERSION ========================="
apt-get install -y -q jq="$JQ_VERSION"

echo "================= Installing CLIs packages ======================"

#Link: https://git-scm.com/downloads
export GIT_VERSION=1:2.*
echo "================= Installing Git $GIT_VERSION ===================="
add-apt-repository ppa:git-core/ppa -y
apt-get update -qq
apt-get install -y -q git="$GIT_VERSION"

echo "================= Installing Gitlfs  ===================="
wget https://github.com/git-lfs/git-lfs/releases/download/v3.4.0/git-lfs-linux-arm64-v3.4.0.tar.gz
tar -xvf git-lfs-linux-arm64-v3.4.0.tar.gz

#Link: https://nodejs.org/en
echo "================= Installing Node18  ===================="
NODEJS_VERSION=v18.18.2
mkdir /node18
pushd /node18

wget https://nodejs.org/dist/$NODEJS_VERSION/node-$NODEJS_VERSION-linux-arm64.tar.xz
tar -xf node-$NODEJS_VERSION-linux-arm64.tar.xz
ln -s /node18/node-$NODEJS_VERSION-linux-arm64/bin/node /usr/local/bin/node18
popd
export PATH=$PATH:/usr/local/bin
echo "Node18 version installed: $(node18 -v)"

echo "================= Adding gcloud =================="
# Reference https://cloud.google.com/sdk/docs/install#deb
echo "deb [signed-by=/usr/share/keyrings/cloud.google.asc] http://packages.cloud.google.com/apt cloud-sdk main" | tee -a /etc/apt/sources.list.d/google-cloud-sdk.list && curl https://packages.cloud.google.com/apt/doc/apt-key.gpg | tee /usr/share/keyrings/cloud.google.asc && apt-get update -y && apt-get install google-cloud-sdk -y

#Link: https://pypi.org/project/awscli/
export AWS_VERSION=1.29.63
echo "================= Adding awscli $AWS_VERSION ===================="
sudo pip3 install awscli=="$AWS_VERSION"

#LInk https://github.com/Azure/azure-cli/releases
AZURE_CLI_VERSION=2.53*
echo "================ Adding azure-cli $AZURE_CLI_VERSION =============="
sudo apt-get install ca-certificates curl apt-transport-https lsb-release gnupg
curl -sL https://packages.microsoft.com/keys/microsoft.asc |
    gpg --dearmor |
    sudo tee /etc/apt/trusted.gpg.d/microsoft.gpg > /dev/null
AZ_REPO=$(lsb_release -cs)
echo "deb [arch=arm64] https://packages.microsoft.com/repos/azure-cli/ $AZ_REPO main" |
    sudo tee /etc/apt/sources.list.d/azure-cli.list
sudo apt-get update && sudo apt-get install -y -q azure-cli=$AZURE_CLI_VERSION

#Link: https://github.com/jfrog/jfrog-cli/releases
JFROG_VERSION=2.50.1
echo "================= Adding jfrog-cli $JFROG_VERSION  ================"
wget -nv https://releases.jfrog.io/artifactory/jfrog-cli/v2-jf/"$JFROG_VERSION"/jfrog-cli-linux-arm64/jf -O jfrog
sudo chmod +x jfrog
sudo mv jfrog /usr/bin/jfrog

#Link: https://kubernetes.io/releases/
KUBECTL_VERSION=1.28.2
echo "================= Adding kubectl $KUBECTL_VERSION ================"
curl -sSLO https://storage.googleapis.com/kubernetes-release/release/v"$KUBECTL_VERSION"/bin/linux/arm64/kubectl
chmod +x ./kubectl
sudo mv ./kubectl /usr/local/bin/kubectl


#Link: https://github.com/helm/helm/releases
HELM_VERSION=3.13.1
echo "================= Adding helm cli $HELM_VERSION ======================================"
curl -sSL -o helm.tar.gz https://get.helm.sh/helm-v"$HELM_VERSION"-linux-arm64.tar.gz
tar xzvf helm.tar.gz
chmod +x ./linux-arm64/helm
sudo cp ./linux-arm64/helm /usr/local/bin/helm3
sudo mv ./linux-arm64/helm /usr/local/bin/helm
rm -fr ./linux-arm64
rm -f helm.tar.gz

#https://developer.hashicorp.com/terraform/downloads
TF_VERSION=1.6.1
echo "================ Adding terraform- $TF_VERSION  ===================="
TF_FILE=terraform_"$TF_VERSION"_linux_arm64.zip

echo "Fetching terraform"
echo "-----------------------------------"
rm -rf /tmp/terraform
mkdir -p /tmp/terraform
wget -nv https://releases.hashicorp.com/terraform/$TF_VERSION/$TF_FILE
unzip -o $TF_FILE -d /tmp/terraform
sudo chmod +x /tmp/terraform/terraform
mv /tmp/terraform/terraform /usr/bin/terraform

#Link: https://developer.hashicorp.com/packer/downloads
PK_VERSION=1.9.4
echo "================ Adding packer $PK_VERSION  ===================="
PK_FILE=packer_"$PK_VERSION"_linux_arm64.zip

echo "Fetching packer"
echo "-----------------------------------"
rm -rf /tmp/packer
mkdir -p /tmp/packer
wget -nv https://releases.hashicorp.com/packer/$PK_VERSION/$PK_FILE
unzip -o $PK_FILE -d /tmp/packer
sudo chmod +x /tmp/packer/packer
mv /tmp/packer/packer /usr/bin/packer

#Link: https://docs.docker.com/compose/release-notes/
DOCKER_COMPOSE=v2.22.0
echo "======= Adding docker compose ======="
sudo curl -L "https://github.com/docker/compose/releases/download/$DOCKER_COMPOSE/docker-compose-$(uname -s)-$(uname -m)" -o /usr/local/bin/docker-compose
sudo chmod +x /usr/local/bin/docker-compose

#Link: https://github.com/docker/buildx/releases
BUILDX_VERSION=0.11.2
echo "======================= buildx version $BUILDX_VERSION"
mkdir -p $HOME/.docker/cli-plugins
wget -O $HOME/.docker/cli-plugins/docker-buildx https://github.com/docker/buildx/releases/download/v"$BUILDX_VERSION"/buildx-v"$BUILDX_VERSION".linux-arm64
chmod +x $HOME/.docker/cli-plugins/docker-buildx
